gradient: The gradient of the objective function

Description Usage Arguments Value Author(s) Examples

View source: R/gradient.R

Description

The gradient function represents the partial derivative of the cost function with respect to each coefficient of the model

Usage

1
gradient(theta, X, y)

Arguments

theta

is a vector containing the parameters or coefficient of the logistic to be estimated

X

is the matrix of our predictor variables with the bias column

y

is a target variable to predict

Value

this function returns a gradient vector

Author(s)

"Saliou NDAO salioundao21@gmail.com"

Examples

1
2
3
4
## Not run: 
  gradient(theta, X, y)

## End(Not run)

Beuleup93/dgrGlm documentation built on Dec. 17, 2021, 10:50 a.m.