logLoss: Logistic regression cost function

Description Usage Arguments Value Author(s) Examples

View source: R/logLoss.R

Description

The cost function, or loss function is the function to be minimized(or maximized) by varying the decision variables.

Usage

1
logLoss(theta, X, y)

Arguments

theta

is a vector containing the parameters or coefficient of the logistic to be estimated

X

is the matrix of our predictor variables with the bias column

y

is a target variable to predict

Value

this function returns a scalar corresponding to the cost for this vector of parameters theta

Author(s)

"Saliou NDAO salioundao21@gmail.com"

Examples

1
2
3
4
## Not run: 
  log_loss(theta, X, y)

## End(Not run)

Beuleup93/dgrGlm documentation built on Dec. 17, 2021, 10:50 a.m.