print.predict: Customization function of the print method for the predict...

Description Usage Arguments

View source: R/surcharge_affichage_predict.R

Description

Customization function of the print method for the predict instance

Usage

1
2
## S3 method for class 'predict'
print(x, ...)

Arguments

x

predict instance returned by dgrglm.predict function

...

other argument


Beuleup93/dgrGlm documentation built on Dec. 17, 2021, 10:50 a.m.