Description Usage Arguments Value Author(s) Examples
The gradient function represents the partial derivative of the cost function with respect to each coefficient of the model
1 | gradient(theta, X, y)
|
theta |
is a vector containing the parameters or coefficient of the logistic to be estimated |
X |
is the matrix of our predictor variables with the bias column |
y |
is a target variable to predict |
this function returns a gradient vector
"Saliou NDAO salioundao21@gmail.com"
1 2 3 4 | ## Not run:
gradient(theta, X, y)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.