Description Usage Arguments Value Author(s) Examples
The cost function, or loss function is the function to be minimized(or maximized) by varying the decision variables.
1 | logLoss(theta, X, y)
|
theta |
is a vector containing the parameters or coefficient of the logistic to be estimated |
X |
is the matrix of our predictor variables with the bias column |
y |
is a target variable to predict |
this function returns a scalar corresponding to the cost for this vector of parameters theta
"Saliou NDAO salioundao21@gmail.com"
1 2 3 4 | ## Not run:
log_loss(theta, X, y)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.